'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var router = require('next/router');
var stringify = require('qs-stringify');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var stringify__default = /*#__PURE__*/_interopDefaultLegacy(stringify);

var RETURN_HREF_QUERY_PARAM = '_UCR_return_href';
/**
 * During contextual routing browser URL will be controlled by Next Router's "as" prop
 * while the page actually rendered is defined by Next Router's "href" prop.
 *
 * During contextual navigation Next Router's behaves as follows:
 * router.asPath:   /item/3               reflects current URL and updates at each page change
 * router.pathname: /search/[terms]       stay the same as long as initial page doesn't change
 * router.query:    {"terms": "foo-bar"}  same as above
 */

function useContextualRouting() {
  var router$1 = router.useRouter();
  var returnHrefQueryParam = router$1.query[RETURN_HREF_QUERY_PARAM];
  var watchedQuery = Object.assign({}, router$1.query);
  delete watchedQuery[RETURN_HREF_QUERY_PARAM];
  /*
   * After a page refresh there is no RETURN_HREF_QUERY_PARAM in router.query
   * RETURN_HREF_QUERY_PARAM is only available in those history entries where
   * contextual navigation is enabled (or WAS enabled in case history.back() is triggered)
   */

  var returnHref = returnHrefQueryParam != null ? returnHrefQueryParam : router$1.asPath; // @NOTE JSON.stringify might be replaced with any hashing solution

  var queryHash = JSON.stringify(watchedQuery);
  var makeContextualHref = react.useCallback(function (extraParams) {
    var _Object$assign;

    return router$1.pathname + '?' + stringify__default['default'](Object.assign({}, router$1.query, extraParams, (_Object$assign = {}, _Object$assign[RETURN_HREF_QUERY_PARAM] = returnHref, _Object$assign)));
  }, [queryHash, returnHref]);
  return {
    returnHref: returnHref,
    makeContextualHref: makeContextualHref
  };
}

exports.RETURN_HREF_QUERY_PARAM = RETURN_HREF_QUERY_PARAM;
exports.useContextualRouting = useContextualRouting;
