import { useCallback } from 'react';
import { useRouter } from 'next/router';
import stringify from 'qs-stringify';

var RETURN_HREF_QUERY_PARAM = '_UCR_return_href';
/**
 * During contextual routing browser URL will be controlled by Next Router's "as" prop
 * while the page actually rendered is defined by Next Router's "href" prop.
 *
 * During contextual navigation Next Router's behaves as follows:
 * router.asPath:   /item/3               reflects current URL and updates at each page change
 * router.pathname: /search/[terms]       stay the same as long as initial page doesn't change
 * router.query:    {"terms": "foo-bar"}  same as above
 */

function useContextualRouting() {
  var router = useRouter();
  var returnHrefQueryParam = router.query[RETURN_HREF_QUERY_PARAM];
  var watchedQuery = Object.assign({}, router.query);
  delete watchedQuery[RETURN_HREF_QUERY_PARAM];
  /*
   * After a page refresh there is no RETURN_HREF_QUERY_PARAM in router.query
   * RETURN_HREF_QUERY_PARAM is only available in those history entries where
   * contextual navigation is enabled (or WAS enabled in case history.back() is triggered)
   */

  var returnHref = returnHrefQueryParam != null ? returnHrefQueryParam : router.asPath; // @NOTE JSON.stringify might be replaced with any hashing solution

  var queryHash = JSON.stringify(watchedQuery);
  var makeContextualHref = useCallback(function (extraParams) {
    var _Object$assign;

    return router.pathname + '?' + stringify(Object.assign({}, router.query, extraParams, (_Object$assign = {}, _Object$assign[RETURN_HREF_QUERY_PARAM] = returnHref, _Object$assign)));
  }, [queryHash, returnHref]);
  return {
    returnHref: returnHref,
    makeContextualHref: makeContextualHref
  };
}

export { RETURN_HREF_QUERY_PARAM, useContextualRouting };
